@@ -27,13 +27,33 @@ class PowergridModule(UpgradeModule):
         )
 
         self.models = {
-            "Line": [("loading_percent", 0.0, 1.0)],
-            "Trafo": [("loading_percent", 0.0, 1.0)],
-            "Bus": [("vm_pu", 0.8, 1.2), ("va_degree", -1.0, 1.0)],
-            "Load": [("p_mw", 0, 1.0), ("q_mvar", -1.0, 1.0)],
-            "Sgen": [("p_mw", 0, 1.0), ("q_mvar", -1.0, 1.0)],
-            "Storage": [("p_mw", 0, 1.0), ("q_mvar", -1.0, 1.0)],
-            "Ext_grid": [("p_mw", 0, 1.0), ("q_mvar", -1.0, 1.0)],
+            "Line": [
+                ("loading_percent", "float", 0.0, 1.0),
+                ("in_service", "bool", 0, 2),
+            ],
+            "Trafo": [("loading_percent", "float", 0.0, 1.0)],
+            "Bus": [
+                ("vm_pu", "float", 0.8, 1.2),
+                ("va_degree", "float", -1.0, 1.0),
+            ],
+            "Load": [
+                ("p_mw", "float", 0, 1.0),
+                ("q_mvar", "float", -1.0, 1.0),
+                ("in_service", "bool", 0, 2),
+            ],
+            "Sgen": [
+                ("p_mw", "float", 0, 1.0),
+                ("q_mvar", "float", -1.0, 1.0),
+                ("in_service", "bool", 0, 2),
+            ],
+            "Storage": [
+                ("p_mw", "float", 0, 1.0),
+                ("q_mvar", "float", -1.0, 1.0),
+            ],
+            "Ext_grid": [
+                ("p_mw", "float", 0, 1.0),
+                ("q_mvar", "float", -1.0, 1.0),
+            ],
         }
 
     def check_module_params(self, module_params: dict):
@@ -145,12 +165,19 @@ class PowergridModule(UpgradeModule):
         for entity in grid.children:
             if entity.type in self.models:
                 for attr in self.models[entity.type]:
-                    name, low, high = attr
+                    name, dtype, low, high = attr
+                    if dtype in ["bool", "int"]:
+                        space = f"Discrete({high})"
+                    else:
+                        space = (
+                            f"Box(low={low}, "
+                            f"high={high}, shape=(1,), dtype=np.float32)"
+                        )
+
                     self.scenario.sensors.append(
                         {
                             "sensor_id": f"{entity.sid}.{entity.eid}.{name}",
-                            "observation_space": f"Box(low={low}, "
-                            f"high={high}, shape=(1,), dtype=np.float32)",
+                            "observation_space": space,
                         }
                     )
         self.scenario.sensors.append(
