@@ -181,9 +181,7 @@ class PandapowerSimulator(mosaik_api.Simulator):
 
         for eid, attrs in inputs.items():
             gidx = eid.split("-")[0]
-            grid = self.models.get(
-                f"Grid-{gidx}", self.models.get(f"GridTS-{gidx}", None)
-            )
+            grid = self.models.get(f"Grid-{gidx}", None)
 
             if grid is None:
                 LOG.critical("No grid found for grid index %s!", gidx)
@@ -195,7 +193,7 @@ class PandapowerSimulator(mosaik_api.Simulator):
             for attr, src_ids in attrs.items():
                 setpoint = 0.0
 
-                for src_id, val in src_ids.items():
+                for val in src_ids.values():
                     setpoint += float(val)
 
                 attrs[attr] = setpoint
